@@ -1,5 +1,5 @@
 run_story('project/create');
-run_story('project/checkpoint/create');
+run_story('project/checkpoint/create', { cp_exists => 0 } );
 
 use lib 't/lib/';
 
