@@ -1,4 +1,4 @@
 run_story('project/create');
-run_story('project/checkpoint/create');
+run_story('project/checkpoint/create', { cp_exists => 0 } );
 run_story('project/checkpoint/remove');
 set_stdout('OK');
